@@ -122,7 +122,7 @@ database_class <- R6::R6Class(
       # nocov start
       while (!is.null(try(self$try_append_lines(lines)))) {
         msg <- paste("Reattempting to append lines to", self$path)
-        cli::cli_alert_info(msg)
+        cli_mark_info(msg)
         Sys.sleep(stats::runif(1, 0.2, 0.25))
         attempt <- attempt + 1L
         if (attempt > max_attempts) {
@@ -272,7 +272,7 @@ database_validate_columns <- function(header, list_columns) {
   if (!all(list_columns %in% header)) {
     tar_throw_validate("all list columns must be in the header")
   }
-  if (!is.null(header) & !("name" %in% header)) {
+  if (!is.null(header) && !("name" %in% header)) {
     tar_throw_validate("header must have a column called \"name\"")
   }
 }
