@@ -1,36 +1,40 @@
 visnetwork_init <- function(
   network,
   label = NULL,
+  label_break = "\n",
   level_separation = NULL,
   degree_from = 1L,
-  degree_to = 1L
+  degree_to = 1L,
+  zoom_speed = 1
 ) {
   visnetwork_new(
     network = network,
     label = label,
+    label_break = label_break,
     level_separation = level_separation,
     degree_from = degree_from,
-    degree_to = degree_to
+    degree_to = degree_to,
+    zoom_speed = zoom_speed
   )
 }
 
 visnetwork_new <- function(
   network = NULL,
   label = NULL,
+  label_break = NULL,
   level_separation = NULL,
   degree_from = NULL,
   degree_to = NULL,
-  legend = NULL,
-  visnetwork = NULL
+  zoom_speed = NULL
 ) {
   visnetwork_class$new(
     network = network,
     label = label,
+    label_break = label_break,
     level_separation = level_separation,
     degree_from = degree_from,
     degree_to = degree_to,
-    legend = legend,
-    visnetwork = visnetwork
+    zoom_speed = zoom_speed
   )
 }
 
@@ -41,45 +45,28 @@ visnetwork_class <- R6::R6Class(
   portable = FALSE,
   cloneable = FALSE,
   public = list(
-    network = NULL,
-    label = NULL,
     level_separation = NULL,
     degree_from = NULL,
     degree_to = NULL,
-    legend = NULL,
-    visnetwork = NULL,
+    zoom_speed = NULL,
     initialize = function(
       network = NULL,
       label = NULL,
+      label_break = NULL,
       level_separation = NULL,
       degree_from = NULL,
       degree_to = NULL,
-      legend = NULL,
-      visnetwork = NULL
+      zoom_speed = NULL
     ) {
       super$initialize(
-        network = network
+        network = network,
+        label = label,
+        label_break = label_break
       )
-      self$label <- label
-      self$legend <- legend
       self$level_separation <- level_separation
       self$degree_from <- degree_from
+      self$zoom_speed <- zoom_speed
       self$degree_to <- degree_to
-      self$visnetwork <- visnetwork
-    },
-    produce_colors = function(status) {
-      colors <- c(
-        built = "#E1BD6D",
-        uptodate = "#354823",
-        outdated = "#78B7C5",
-        started = "#DC863B",
-        canceled = "#FAD510",
-        errored = "#C93312",
-        queued = "#D2D2D0",
-        skipped = "#7500D1",
-        none = "#94a4ac"
-      )
-      colors[status]
     },
     produce_shapes = function(type) {
       shapes <- c(
@@ -90,9 +77,6 @@ visnetwork_class <- R6::R6Class(
       )
       shapes[type]
     },
-    produce_labels = function(vertices) {
-      vertices$name
-    },
     produce_legend = function() {
       vertices <- self$network$vertices
       colors <- vertices[vertices$status != "none", c("status", "color")]
@@ -109,11 +93,10 @@ visnetwork_class <- R6::R6Class(
       legend$label <- capitalize(legend$label)
       legend
     },
-    produce_visnetwork = function() {
+    produce_visual = function() {
       tar_assert_package("visNetwork")
       vertices <- self$network$vertices
       edges <- self$network$edges
-      vertices <- self$update_label(vertices)
       out <- visNetwork::visNetwork(nodes = vertices, edges = edges, main = "")
       out <- visNetwork::visNodes(out, physics = FALSE)
       out <- visNetwork::visEdges(
@@ -126,7 +109,10 @@ visnetwork_class <- R6::R6Class(
         highlightNearest = list(
           enabled = TRUE,
           algorithm = "hierarchical",
-          degree = list(from = self$degree_from, to = self$degree_to)
+          degree = list(
+            from = min(self$degree_from, nrow(vertices)),
+            to = min(self$degree_to, nrow(vertices))
+          )
         )
       )
       out <- visNetwork::visLegend(
@@ -140,35 +126,18 @@ visnetwork_class <- R6::R6Class(
         graph = out,
         stabilization = FALSE
       )
+      out <- visNetwork::visInteraction(
+        graph = out,
+        zoomSpeed = self$zoom_speed
+      )
       visNetwork::visHierarchicalLayout(
         graph = out,
         direction = "LR",
         levelSeparation = self$level_separation
       )
     },
-    update_label = function(vertices) {
-      seconds <- format_seconds(vertices$seconds)
-      bytes <- format_bytes(vertices$bytes)
-      branches <- format_branches(vertices$branches)
-      if ("time" %in% label) {
-        vertices$label <- paste(vertices$label, seconds, sep = "\n")
-      }
-      if ("size" %in% label) {
-        vertices$label <- paste(vertices$label, bytes, sep = "\n")
-      }
-      if ("branches" %in% label) {
-        vertices$label <- paste(vertices$label, branches, sep = "\n")
-      }
-      vertices
-    },
-    update_visnetwork = function() {
-      self$visnetwork <- self$produce_visnetwork()
-    },
-    update_labels = function() {
-      vertices <- self$network$vertices
-      vertices$id <- vertices$name
-      vertices$label <- self$produce_labels(vertices)
-      self$network$vertices <- vertices
+    update_ids = function() {
+      self$network$vertices$id <- self$network$vertices$name
     },
     update_arrows = function() {
       edges <- self$network$edges
@@ -183,37 +152,21 @@ visnetwork_class <- R6::R6Class(
       vertices <- position_level(vertices, self$network$edges)
       self$network$vertices <- vertices
     },
-    update_colors = function() {
-      vertices <- self$network$vertices
-      vertices$color <- self$produce_colors(vertices$status)
-      self$network$vertices <- vertices
-    },
     update_shapes = function() {
       vertices <- self$network$vertices
       vertices$shape <- self$produce_shapes(vertices$type)
       self$network$vertices <- vertices
     },
-    update_legend = function() {
-      self$legend <- self$produce_legend()
-    },
-    update = function() {
-      self$update_network()
-      self$update_labels()
+    update_extra = function() {
+      self$update_ids()
       self$update_positions()
       self$update_arrows()
-      self$update_colors()
       self$update_shapes()
-      self$update_legend()
-      self$update_visnetwork()
     },
     validate = function() {
       super$validate()
-      tar_assert_in(self$label, c("time", "size", "branches"))
-      if (!is.null(self$legend)) {
-        tar_assert_df(self$legend)
-      }
-      if (!is.null(self$visnetwork)) {
-        tar_assert_identical(class(self$visnetwork)[1], "visNetwork")
+      if (!is.null(self$visual)) {
+        tar_assert_identical(class(self$visual)[1], "visNetwork")
       }
       tar_assert_scalar(self$degree_from)
       tar_assert_scalar(self$degree_to)
@@ -221,6 +174,9 @@ visnetwork_class <- R6::R6Class(
       tar_assert_dbl(self$degree_to)
       tar_assert_ge(self$degree_from, 0L)
       tar_assert_ge(self$degree_to, 0L)
+      tar_assert_scalar(self$zoom_speed)
+      tar_assert_dbl(self$zoom_speed)
+      tar_assert_positive(self$zoom_speed)
     }
   )
 )
