@@ -13,7 +13,7 @@
 #' tar_target(x, 1)$settings$format
 #' tar_option_reset() # reset all options
 #' tar_target(x, 1)$settings$format
-#' if (identical(Sys.getenv("TAR_LONG_EXAMPLES"), "true")) {
+#' if (identical(Sys.getenv("TAR_EXAMPLES"), "true")) {
 #' tar_dir({ # tar_dir() runs code from a temporary directory.
 #' tar_script({
 #'   tar_option_set(cue = tar_cue(mode = "always"))
@@ -25,6 +25,6 @@
 #' })
 #' }
 tar_option_reset <- function() {
-  remove(list = names(tar_envir_options), envir = tar_envir_options)
+  tar_options$reset()
   invisible()
 }
